Functions
- atomic_
write - Write
contenttopathatomically using a temp-file + rename pattern. Prevents file corruption if the process is interrupted mid-write.
content to path atomically using a temp-file + rename pattern.
Prevents file corruption if the process is interrupted mid-write.